from .convert import remove_duplicates, str_to_dict
from .wait import waiter
from .shortcut import create_shortcut
from .notifications import desktop_msg
from .format import table
from .stripping import rma_str
from .music import play_music

__all__ = ["remove_duplicates", "waiter", "create_shortcut", "desktop_msg", "table", "rma_str", "play_music", "str_to_dict"]